@@ -211,9 +211,9 @@ def read_dcd(filename, topology=None):
         if any(np.ndarray((n_structures,), endian + 'i', buffer, offset=off3, strides=(80 + 12 * n_atoms)) != n_byte):
             raise IOError('failed reading DCD file')
         return r
-    x = _xyz(56, 60, 60 + 4 * n_atoms)
+    x = _xyz(56 + 0 * n_atoms, 60 + 0 * n_atoms, 60 + 4 * n_atoms)
     y = _xyz(64 + 4 * n_atoms, 68 + 4 * n_atoms, 68 + 8 * n_atoms)
-    z = _xyz(72 + 8 * n_atoms, 76 + 8 * n_atoms, 72 + 12 * n_atoms)
+    z = _xyz(72 + 8 * n_atoms, 76 + 8 * n_atoms, 76 + 12 * n_atoms)
 
     # Create Trajectory and return
     return Trajectory(np.vstack([x, y, z]), box=np.vstack([box_x, box_y, box_z]), topology=topology)
